15.102. cdist-type__package_upgrade_all(7) — cdist 4.10.4 documentation

# 15.102. cdist-type__package_upgrade_all(7)

## 15.102.1. NAME

cdist-type__package_upgrade_all - Upgrade all the installed packages

## 15.102.2. DESCRIPTION

This cdist type allows you to upgrade all the installed packages on the target. It will automatically use the appropriate package manager.

## 15.102.3. REQUIRED PARAMETERS

None

## 15.102.4. OPTIONAL PARAMETERS

type
  The package manager to use. Default is determined based on the $os explorer variable. e.g. * apt for Debian * yum for Red Hat * pacman for Arch Linux

## 15.102.5. BOOLEAN PARAMETERS

apt-dist-upgrade
  Do dist-upgrade instead of upgrade.
apt-clean
  Clean out the local repository of retrieved package files.

## 15.102.6. EXAMPLES

    # Upgrade all the installed packages on the target
    __package_upgrade_all

    # Force use of a specific package manager
    __package_upgrade_all --type apt

## 15.102.7. AUTHORS

Ricardo Catalinas Jiménez <jimenezrick--@--gmail.com>

## 15.102.8. COPYING

Copyright (C) 2014 Ricardo Catalinas Jiménez. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.